#include "Qn.h"

namespace Dmrg
{

Qn::VectorModalStructType Qn::modalStruct;
bool Qn::ifPresentOther0IsElectrons = true;

}
